@@ -19,8 +19,8 @@ Routines for configuring Tacker
 
 import os
 
-from oslo import messaging
 from oslo_config import cfg
+import oslo_messaging
 from paste import deploy
 
 from tacker.common import utils
@@ -40,6 +40,8 @@ core_opts = [
                help=_("The API paste config file to use")),
     cfg.StrOpt('api_extensions_path', default="",
                help=_("The path for API extensions")),
+    cfg.ListOpt('service_plugins', default=[],
+                help=_("The service plugins Tacker will use")),
     cfg.StrOpt('policy_file', default="policy.json",
                help=_("The policy file to use")),
     cfg.StrOpt('auth_strategy', default='keystone',
@@ -91,7 +93,7 @@ cfg.CONF.register_opts(core_opts)
 cfg.CONF.register_cli_opts(core_cli_opts)
 
 # Ensure that the control exchange is set correctly
-messaging.set_transport_defaults(control_exchange='tacker')
+oslo_messaging.set_transport_defaults(control_exchange='tacker')
 _SQL_CONNECTION_DEFAULT = 'sqlite://'
 # Update the default QueuePool parameters. These can be tweaked by the
 # configuration variables - max_pool_size, max_overflow and pool_timeout
