@@ -23,17 +23,21 @@ import functools
 import hashlib
 import logging as std_logging
 import multiprocessing
-import netaddr
 import os
 import random
 import signal
 import socket
+import sys
 import uuid
 
 from eventlet.green import subprocess
+import netaddr
 from oslo_config import cfg
+from oslo_utils import importutils
+from stevedore import driver
 
 from tacker.common import constants as q_const
+from tacker.i18n import _LE
 from tacker.openstack.common import lockutils
 from tacker.openstack.common import log as logging
 
@@ -41,7 +45,29 @@ from tacker.openstack.common import log as logging
 TIME_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
 LOG = logging.getLogger(__name__)
 SYNCHRONIZED_PREFIX = 'tacker-'
-
+MEM_UNITS = {
+    "MB": {
+        "MB": {
+            "op": "*",
+            "val": "1"
+        },
+        "GB": {
+            "op": "/",
+            "val": "1024"
+        }
+    },
+    "GB": {
+        "MB": {
+            "op": "*",
+            "val": "1024"
+        },
+        "GB": {
+            "op": "*",
+            "val": "1"
+        }
+    }
+}
+CONF = cfg.CONF
 synchronized = lockutils.synchronized_with_prefix(SYNCHRONIZED_PREFIX)
 
 
@@ -310,15 +336,59 @@ def is_valid_ipv4(address):
         return False
 
 
-def deprecated(name):
-    """On the basis of tacker version, this decorator
+def change_memory_unit(mem, to):
+    """Changes the memory value(mem) based on the unit('to') specified.
 
-    can be used to mark a call as deprecated.
+    If the unit is not specified in 'mem', by default, it is considered
+    as "MB". And this method returns only integer.
     """
-    def _deprecate(func):
-        @functools.wraps(func)
-        def wrapper(*args, **kwargs):
-            LOG.deprecated("Call to %s deprecated, avoid its usage" % name)
-            return func(*args, **kwargs)
-        return wrapper
-    return _deprecate
+
+    mem = str(mem) + " MB" if str(mem).isdigit() else mem.upper()
+    for unit, value in MEM_UNITS.iteritems():
+        mem_arr = mem.split(unit)
+        if len(mem_arr) < 2:
+            continue
+        return eval(mem_arr[0] +
+                    MEM_UNITS[unit][to]["op"] +
+                    MEM_UNITS[unit][to]["val"])
+
+
+def load_class_by_alias_or_classname(namespace, name):
+    """Load class using stevedore alias or the class name
+
+    Load class using the stevedore driver manager
+    :param namespace: namespace where the alias is defined
+    :param name: alias or class name of the class to be loaded
+    :returns class if calls can be loaded
+    :raises ImportError if class cannot be loaded
+    """
+
+    if not name:
+        LOG.error(_LE("Alias or class name is not set"))
+        raise ImportError(_("Class not found."))
+    try:
+        # Try to resolve class by alias
+        mgr = driver.DriverManager(namespace, name)
+        class_to_load = mgr.driver
+    except RuntimeError:
+        e1_info = sys.exc_info()
+        # Fallback to class name
+        try:
+            class_to_load = importutils.import_class(name)
+        except (ImportError, ValueError):
+            LOG.error(_LE("Error loading class by alias"),
+                      exc_info=e1_info)
+            LOG.error(_LE("Error loading class by class name"),
+                      exc_info=True)
+            raise ImportError(_("Class not found."))
+    return class_to_load
+
+
+def deep_update(orig_dict, new_dict):
+    for key, value in new_dict.items():
+        if isinstance(value, dict):
+            if key in orig_dict and isinstance(orig_dict[key], dict):
+                deep_update(orig_dict[key], value)
+                continue
+
+        orig_dict[key] = value
