@@ -15,24 +15,22 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author: Isaku Yamahata, Intel Corporation.
 
 import abc
 import inspect
-import six
 import threading
 import time
 
-from keystoneclient.v2_0 import client as ks_client
 from oslo_config import cfg
 from oslo_utils import timeutils
+import six
 
+from tacker.common import clients
 from tacker.common import driver_manager
 from tacker import context as t_context
 from tacker.openstack.common import jsonutils
 from tacker.openstack.common import log as logging
-from tacker.vm.drivers.heat import heat
+from tacker.vm.infra_drivers.heat import heat
 
 
 LOG = logging.getLogger(__name__)
@@ -46,7 +44,7 @@ CONF.register_opts(OPTS, group='monitor')
 
 
 class VNFMonitor(object):
-    """VNF Monitor"""
+    """VNF Monitor."""
 
     _instance = None
     _hosting_vnfs = dict()   # device_id => dict of parameters
@@ -54,13 +52,13 @@ class VNFMonitor(object):
     _lock = threading.RLock()
 
     OPTS = [
-        cfg.MultiStrOpt(
-            'monitor_driver', default=[],
+        cfg.ListOpt(
+            'monitor_driver', default=['ping', 'http_ping'],
             help=_('Monitor driver to communicate with '
                    'Hosting VNF/logical service '
-                   'instance servicevm plugin will use')),
+                   'instance tacker plugin will use')),
     ]
-    cfg.CONF.register_opts(OPTS, 'servicevm')
+    cfg.CONF.register_opts(OPTS, 'tacker')
 
     def __new__(cls, boot_wait, check_intvl=None):
         if not cls._instance:
@@ -69,8 +67,8 @@ class VNFMonitor(object):
 
     def __init__(self, boot_wait, check_intvl=None):
         self._monitor_manager = driver_manager.DriverManager(
-            'tacker.servicevm.monitor.drivers',
-            cfg.CONF.servicevm.monitor_driver)
+            'tacker.tacker.monitor.drivers',
+            cfg.CONF.tacker.monitor_driver)
 
         self.boot_wait = boot_wait
         if check_intvl is None:
@@ -116,15 +114,15 @@ class VNFMonitor(object):
             hosting_vnf = self._hosting_vnfs.pop(device_id, None)
             if hosting_vnf:
                 LOG.debug('deleting device_id %(device_id)s, Mgmt IP %(ips)s',
-                        {'device_id': device_id,
-                         'ips': hosting_vnf['management_ip_addresses']})
+                          {'device_id': device_id,
+                           'ips': hosting_vnf['management_ip_addresses']})
 
     def run_monitor(self, hosting_vnf):
         mgmt_ips = hosting_vnf['management_ip_addresses']
         vdupolicies = hosting_vnf['monitoring_policy']['vdus']
 
         vnf_delay = hosting_vnf['monitoring_policy'].get(
-                        'monitoring_delay', self.boot_wait)
+            'monitoring_delay', self.boot_wait)
 
         for vdu in vdupolicies.keys():
             if hosting_vnf.get('dead'):
@@ -137,8 +135,8 @@ class VNFMonitor(object):
                 vdu_delay = params.get('monitoring_delay', vnf_delay)
 
                 if not timeutils.is_older_than(
-                            hosting_vnf['boot_at'],
-                            vdu_delay):
+                    hosting_vnf['boot_at'],
+                        vdu_delay):
                         continue
 
                 actions = policy[driver].get('actions', {})
@@ -173,7 +171,7 @@ class VNFMonitor(object):
 
     def monitor_call(self, driver, device_dict, kwargs):
         return self._invoke(driver,
-            device=device_dict, kwargs=kwargs)
+                            device=device_dict, kwargs=kwargs)
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -207,10 +205,6 @@ class ActionPolicy(object):
     def get_supported_actions(cls):
         return cls._POLICIES.keys()
 
-    @abc.abstractmethod
-    def execute_action(cls, plugin, device_dict):
-        pass
-
 
 @ActionPolicy.register('respawn')
 class ActionRespawn(ActionPolicy):
@@ -228,14 +222,8 @@ class ActionRespawn(ActionPolicy):
             LOG.debug(_('new_device %s'), new_device)
 
             # keystone v2.0 specific
-            auth_url = CONF.keystone_authtoken.auth_uri + '/v2.0'
             authtoken = CONF.keystone_authtoken
-            kc = ks_client.Client(
-                tenant_name=authtoken.project_name,
-                username=authtoken.username,
-                password=authtoken.password,
-                auth_url=auth_url)
-            token = kc.service_catalog.get_token()
+            token = clients.OpenstackClients().auth_token
 
             context = t_context.get_admin_context()
             context.tenant_name = authtoken.project_name
@@ -251,7 +239,7 @@ class ActionRespawn(ActionPolicy):
 @ActionPolicy.register('respawn', 'heat')
 class ActionRespawnHeat(ActionPolicy):
     @classmethod
-    def execute_action(cls, plugin, device_dict):
+    def execute_action(cls, plugin, device_dict, auth_attr):
         device_id = device_dict['id']
         LOG.error(_('device %s dead'), device_id)
         if plugin._mark_device_dead(device_dict['id']):
@@ -269,37 +257,19 @@ class ActionRespawnHeat(ActionPolicy):
             attributes = device_dict['attributes'].copy()
             attributes['dead_device_id'] = device_id
             new_device = {'id': new_device_id, 'attributes': attributes}
-            for key in ('tenant_id', 'template_id', 'name'):
+            for key in ('tenant_id', 'template_id', 'name', 'vim_id',
+                        'placement_attr'):
                 new_device[key] = device_dict[key]
             LOG.debug(_('new_device %s'), new_device)
-
+            placement_attr = device_dict.get('placement_attr', {})
+            region_name = placement_attr.get('region_name', None)
             # kill heat stack
-            heatclient = heat.HeatClient(None)
+            heatclient = heat.HeatClient(auth_attr=auth_attr,
+                                         region_name=region_name)
             heatclient.delete(device_dict['instance_id'])
 
-            # TODO(sripriya): sleep timer has been provided as a temporary
-            # workaround for the nova neutron port still in use issue. Need
-            # to come up with a better fix for the issue
-            LOG.debug('Sleeping for 10 seconds before initiating respawn')
-            time.sleep(10)
-
-            # keystone v2.0 specific
-            auth_url = CONF.keystone_authtoken.auth_uri + '/v2.0'
-            authtoken = CONF.keystone_authtoken
-            kc = ks_client.Client(
-                tenant_name=authtoken.project_name,
-                username=authtoken.username,
-                password=authtoken.password,
-                auth_url=auth_url)
-            token = kc.service_catalog.get_token()
-
+            # TODO(anyone) set the current request ctxt instead of admin ctxt
             context = t_context.get_admin_context()
-            context.tenant_name = authtoken.project_name
-            context.user_name = authtoken.username
-            context.auth_token = token['id']
-            context.tenant_id = token['tenant_id']
-            context.user_id = token['user_id']
-
             new_device_dict = plugin.create_device_sync(
                 context, {'device': new_device})
             LOG.info(_('respawned new device %s'), new_device_dict['id'])
@@ -307,9 +277,9 @@ class ActionRespawnHeat(ActionPolicy):
             # ungly hack to keep id unchanged
             dead_device_id = device_id + '-DEAD-' + failure_count_str
             LOG.debug(_('%(dead)s %(new)s %(cur)s'),
-                  {'dead': dead_device_id,
-                   'new': new_device_id,
-                   'cur': device_id})
+                      {'dead': dead_device_id,
+                       'new': new_device_id,
+                       'cur': device_id})
             plugin.rename_device_id(context, device_id, dead_device_id)
             plugin.rename_device_id(context, new_device_id, device_id)
             LOG.debug('Delete dead device')
@@ -319,7 +289,7 @@ class ActionRespawnHeat(ActionPolicy):
                 new_device_dict.setdefault('attributes', {})['config'] = config
 
             plugin.config_device(context, new_device_dict)
-            plugin.add_device_to_monitor(new_device_dict)
+            plugin.add_device_to_monitor(new_device_dict, auth_attr)
 
 
 @ActionPolicy.register('log')
